{% extends "admin/change_list.html" %}

{% load admin_list i18n static %}

{% block extrahead %}{{ block.super }}
<link type='text/css' rel='stylesheet' href='{{ PAGES_STATIC_URL }}css/font-awesome.min.css' />
<style>
i.fa {
	font-size:40px;
}
</style>
{% endblock %}
