# Generated by Django 2.1.3 on 2018-11-02 08:18

from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0007_language_code'),
    ]

    operations = [
        migrations.AlterField(
            model_name='media',
            name='extension',
            field=models.CharField(blank=True, editable=False, max_length=32),
        ),
        migrations.AlterField(
            model_name='page',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='pages.Page', verbose_name='parent'),
        ),
        migrations.AlterField(
            model_name='page',
            name='redirect_to',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='redirected_pages', to='pages.Page', verbose_name='redirect to'),
        ),
        migrations.AlterField(
            model_name='page',
            name='redirect_to_url',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='redirect to url'),
        ),
        migrations.AlterField(
            model_name='pagealias',
            name='page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='pages.Page', verbose_name='page'),
        ),
    ]
