<script type="text/javascript">
<!--
    if(window.$) {
        $(document).ready(function() {
            if($.fn.rte) {
                $('#id_{{ name }}').rte('{{ PAGES_STATIC_URL }}', '{{ PAGES_MEDIA_URL }}');
            }
        });
    }
-->
</script>
