{% load pages_tags %}

{% placeholder name1 %}

{% placeholder name2 %}

{% placeholder name3 %}

{% placeholder name4 %}

{% placeholder name5 %}

{% placeholder name6 block %}

{% endplaceholder %}

{% placeholder name7 %}

{% placeholder name8 block %}

{% endplaceholder %}

{% placeholder name9 %}

{% placeholder name10 %}

{% placeholder name11 %}

{% placeholder name12 %}

{% placeholder name13 block %}

{% endplaceholder %}