# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-01-19 05:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0004_auto_20161209_0648'),
    ]

    operations = [
        migrations.CreateModel(
            name='Media',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=255)),
                ('description', models.TextField(blank=True)),
                ('url', models.FileField(upload_to='')),
                ('extension', models.CharField(blank=True, max_length=32)),
            ],
            options={
                'verbose_name_plural': 'Medias',
            },
        ),
    ]
