#!/usr/bin/env python3
"""Django's command-line utility for administrative tasks."""
import os
import sys

example_dir = os.path.dirname(__file__)
sys.path.insert(0, os.path.join(example_dir, '..'))

def main():
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    main()
