{% extends "admin/change_list.html" %}

{% load admin_list i18n pages_tags static %}

{% block coltype %}flex{% endblock %}

{% block extrahead %}{{ block.super }}
<script type="text/javascript">var static_url = "{% get_static_prefix %}";</script>
{% endblock %}

{% block bodyclass %}{{ block.super }} change-list-pages{% endblock %}

{% block result_list %}
<div id="toolbar" class="actions">
<form id="changelist-search" action="" method="post">
    {% csrf_token %}
    <div>
        <label for="searchbar"><img src="{% static "admin/img/search.svg" %}" alt="{% trans "Search" %}" /></label>
        <input type="text" size="40" name="q" value="{{ q }}" id="searchbar" />
        <button type="submit" class="button" name="g">{% trans 'Search' %}</button>
    </div>
</form>
</div>

<form method="post" action="">
{% csrf_token %}
{% if action_form and actions_on_top and cl.full_result_count %}{% admin_actions %}{% endif %}

<div id="page-list">
{% include "admin/pages/page/change_list_table.html" %}
</div>
{% if action_form and actions_on_bottom and cl.full_result_count %}{% admin_actions %}{% endif %}
</form>

{% endblock %}

{% block pagination %}{% endblock %}
