# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-12-09 06:48
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0003_page_uuid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='content',
            name='page',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='pages.Page', verbose_name='page'),
        ),
    ]
